@@ -1,5 +1,6 @@
+from django.conf.urls import patterns, url
 from django.contrib import admin
-from django.urls import reverse, re_path
+from django.core.urlresolvers import reverse
 from django.http import HttpResponseRedirect
 from .models import FileBrowser
 from .settings import SHOW_IN_DASHBOARD
@@ -15,11 +16,10 @@ class FileBrowserAdmin(admin.ModelAdmin):
         return False
 
     def get_urls(self):
-        opts = self.model._meta
-        info = opts.app_label, (opts.model_name if hasattr(opts, 'model_name') else opts.module_name)
-        return [
-            re_path('^$', self.admin_site.admin_view(self.filebrowser_view), name='{0}_{1}_changelist'.format(*info)),
-        ]
+        info = self.model._meta.app_label, self.model._meta.module_name
+        return patterns('',
+            url('^$', self.admin_site.admin_view(self.filebrowser_view), name='{0}_{1}_changelist'.format(*info)),
+        )
 
     def filebrowser_view(self, request):
         return HttpResponseRedirect(reverse('filebrowser:fb_browse'))
