@@ -1,50 +1,58 @@
 # coding: utf-8
 
+# PYTHON IMPORTS
 import os
 import re
-import json
-from time import gmtime, strftime, localtime, time
+from time import gmtime
+from time import strftime
+from time import localtime
+from time import time
 
-from django import forms
-from django import VERSION as DJANGO_VERSION
-from django.contrib import messages
-from django.contrib.admin.sites import site as admin_site
-from django.utils.module_loading import import_string 
-from django.contrib.admin.views.decorators import staff_member_required
-from django.core.files.storage import DefaultStorage, default_storage, FileSystemStorage
-from django.core.paginator import Paginator, InvalidPage, EmptyPage
-from django.urls import path, reverse, get_urlconf, get_resolver
+# DJANGO IMPORTS
+from django.shortcuts import render_to_response, HttpResponse
+from django.template import RequestContext as Context
 from django.http import HttpResponseRedirect, HttpResponseBadRequest
-from django.shortcuts import HttpResponse
-from django.template.response import TemplateResponse
-from django.utils.encoding import smart_str
-from django.utils.translation import gettext as _
+from django.contrib.admin.views.decorators import staff_member_required
 from django.views.decorators.cache import never_cache
+from django.utils.translation import ugettext as _
+from django import forms
+from django.core.urlresolvers import reverse, get_urlconf, get_resolver
+from django.core.paginator import Paginator, InvalidPage, EmptyPage
+from django.utils.encoding import smart_text
+from django.contrib import messages
 from django.views.decorators.clickjacking import xframe_options_sameorigin
 from django.views.decorators.csrf import csrf_exempt
+from django.core.files.storage import DefaultStorage, default_storage, FileSystemStorage
 
-from filebrowser import signals
+# FILEBROWSER IMPORTS
+from filebrowser.settings import STRICT_PIL, DIRECTORY, EXTENSIONS, SELECT_FORMATS, ADMIN_VERSIONS, ADMIN_THUMBNAIL, MAX_UPLOAD_SIZE,\
+    NORMALIZE_FILENAME, CONVERT_FILENAME, SEARCH_TRAVERSE, EXCLUDE, VERSIONS, EXTENSION_LIST, DEFAULT_SORTING_BY, DEFAULT_SORTING_ORDER,\
+    LIST_PER_PAGE, OVERWRITE_EXISTING
+from filebrowser.templatetags.fb_tags import query_helper
 from filebrowser.base import FileListing, FileObject
 from filebrowser.decorators import path_exists, file_exists
-from filebrowser.storage import FileSystemStorageMixin
-from filebrowser.templatetags.fb_tags import query_helper
+from filebrowser.storage import FileSystemStorageMixin, StorageMixin
 from filebrowser.utils import convert_filename
-from filebrowser.settings import (DIRECTORY, EXTENSIONS, SELECT_FORMATS, ADMIN_VERSIONS, ADMIN_THUMBNAIL, 
-    MAX_UPLOAD_SIZE, NORMALIZE_FILENAME, CONVERT_FILENAME, SEARCH_TRAVERSE, EXCLUDE, VERSIONS, 
-    VERSIONS_BASEDIR, EXTENSION_LIST, DEFAULT_SORTING_BY, DEFAULT_SORTING_ORDER, LIST_PER_PAGE,
-    OVERWRITE_EXISTING, DEFAULT_PERMISSIONS, UPLOAD_TEMPDIR, ADMIN_CUSTOM
-)
-
-
-
-# This use admin_custom and not admin.sites.site of Django.
-admin_site = import_string(ADMIN_CUSTOM) if ADMIN_CUSTOM else admin_site
-
+from filebrowser import signals
 
 # Add some required methods to FileSystemStorage
 if FileSystemStorageMixin not in FileSystemStorage.__bases__:
     FileSystemStorage.__bases__ += (FileSystemStorageMixin,)
 
+# PIL import
+if STRICT_PIL:
+    from PIL import Image
+else:
+    try:
+        from PIL import Image
+    except ImportError:
+        import Image
+
+# JSON import
+try:
+    import json
+except ImportError:
+    from django.utils import simplejson as json
 
 # This cache contains all *instantiated* FileBrowser sites
 _sites_cache = {}
@@ -55,7 +63,7 @@ def get_site_dict(app_name='filebrowser'):
     Return a dict with all *deployed* FileBrowser sites that have
     a given app_name.
     """
-    if app_name not in _sites_cache:
+    if not app_name in _sites_cache:
         return {}
     # Get names of all deployed filebrowser sites with a give app_name
     deployed = get_resolver(get_urlconf()).app_dict[app_name]
@@ -67,7 +75,7 @@ def register_site(app_name, site_name, site):
     """
     Add a site into the site dict.
     """
-    if app_name not in _sites_cache:
+    if not app_name in _sites_cache:
         _sites_cache[app_name] = {}
     _sites_cache[app_name][site_name] = site
 
@@ -83,7 +91,7 @@ def get_default_site(app_name='filebrowser'):
 
     # Django's default name resolution method (see django.core.urlresolvers.reverse())
     app_list = resolver.app_dict[app_name]
-    if name not in app_list:
+    if not name in app_list:
         name = app_list[0]
 
     return get_site_dict()[name]
@@ -114,11 +122,11 @@ def get_filterdate(filter_date, date_time):
     date_day = strftime("%d", gmtime(date_time))
     if filter_date == 'today' and int(date_year) == int(localtime()[0]) and int(date_month) == int(localtime()[1]) and int(date_day) == int(localtime()[2]):
         returnvalue = 'true'
-    elif filter_date == 'thismonth' and date_time >= time() - 2592000:
+    elif filter_date == 'thismonth' and date_time >= time()-2592000:
         returnvalue = 'true'
     elif filter_date == 'thisyear' and int(date_year) == int(localtime()[0]):
         returnvalue = 'true'
-    elif filter_date == 'past7days' and date_time >= time() - 604800:
+    elif filter_date == 'past7days' and date_time >= time()-604800:
         returnvalue = 'true'
     elif filter_date == '':
         returnvalue = 'true'
@@ -172,7 +180,6 @@ class FileBrowserSite(object):
     """
     A filebrowser.site defines admin views for browsing your servers media files.
     """
-    filelisting_class = FileListing
 
     def __init__(self, name=None, app_name='filebrowser', storage=default_storage):
         self.name = name
@@ -199,17 +206,25 @@ class FileBrowserSite(object):
     directory = property(_directory_get, _directory_set)
 
     def get_urls(self):
+        "URLs for a filebrowser.site"
+        try:
+            from django.conf.urls import url, patterns
+        except ImportError:
+            # for Django version less then 1.4
+            from django.conf.urls.defaults import url, patterns
+
         # filebrowser urls (views)
-        urlpatterns = [
-            path('browse/', path_exists(self, filebrowser_view(self.browse)), name="fb_browse"),
-            path('createdir/', path_exists(self, filebrowser_view(self.createdir)), name="fb_createdir"),
-            path('upload/', path_exists(self, filebrowser_view(self.upload)), name="fb_upload"),
-            path('delete_confirm/', file_exists(self, path_exists(self, filebrowser_view(self.delete_confirm))), name="fb_delete_confirm"),
-            path('delete/', file_exists(self, path_exists(self, filebrowser_view(self.delete))), name="fb_delete"),
-            path('detail/', file_exists(self, path_exists(self, filebrowser_view(self.detail))), name="fb_detail"),
-            path('version/', file_exists(self, path_exists(self, filebrowser_view(self.version))), name="fb_version"),
-            path('upload_file/', staff_member_required(csrf_exempt(self._upload_file)), name="fb_do_upload"),
-        ]
+        urlpatterns = patterns(
+            '',
+            url(r'^browse/$', path_exists(self, filebrowser_view(self.browse)), name="fb_browse"),
+            url(r'^createdir/', path_exists(self, filebrowser_view(self.createdir)), name="fb_createdir"),
+            url(r'^upload/', path_exists(self, filebrowser_view(self.upload)), name="fb_upload"),
+            url(r'^delete_confirm/$', file_exists(self, path_exists(self, filebrowser_view(self.delete_confirm))), name="fb_delete_confirm"),
+            url(r'^delete/$', file_exists(self, path_exists(self, filebrowser_view(self.delete))), name="fb_delete"),
+            url(r'^detail/$', file_exists(self, path_exists(self, filebrowser_view(self.detail))), name="fb_detail"),
+            url(r'^version/$', file_exists(self, path_exists(self, filebrowser_view(self.version))), name="fb_version"),
+            url(r'^upload_file/$', staff_member_required(csrf_exempt(self._upload_file)), name="fb_do_upload"),
+        )
         return urlpatterns
 
     def add_action(self, action, name=None):
@@ -269,12 +284,9 @@ class FileBrowserSite(object):
         filter_re = []
         for exp in EXCLUDE:
             filter_re.append(re.compile(exp))
-
-        # do not filter if VERSIONS_BASEDIR is being used
-        if not VERSIONS_BASEDIR:
-            for k, v in VERSIONS.items():
-                exp = (r'_%s(%s)$') % (k, '|'.join(EXTENSION_LIST))
-                filter_re.append(re.compile(exp, re.IGNORECASE))
+        for k, v in VERSIONS.items():
+            exp = (r'_%s(%s)$') % (k, '|'.join(EXTENSION_LIST))
+            filter_re.append(re.compile(exp, re.IGNORECASE))
 
         def filter_browse(item):
             "Defining a browse filter"
@@ -289,7 +301,7 @@ class FileBrowserSite(object):
         query = request.GET.copy()
         path = u'%s' % os.path.join(self.directory, query.get('dir', ''))
 
-        filelisting = self.filelisting_class(
+        filelisting = FileListing(
             path,
             filter_func=filter_browse,
             sorting_by=query.get('o', DEFAULT_SORTING_BY),
@@ -332,23 +344,18 @@ class FileBrowserSite(object):
         except (EmptyPage, InvalidPage):
             page = p.page(p.num_pages)
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/index.html', dict(
-            admin_site.each_context(request),
-            **{
-                'p': p,
-                'page': page,
-                'filelisting': filelisting,
-                'query': query,
-                'title': _(u'FileBrowser'),
-                'is_popup': "pop" in request.GET,   # ChangeList uses "pop"
-                'settings_var': get_settings_var(directory=self.directory),
-                'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
-                'breadcrumbs_title': "",
-                'filebrowser_site': self,
-                'old_design': DJANGO_VERSION < (1, 9)
-            }
-        ))
+        return render_to_response('filebrowser/index.html', {
+            'p': p,
+            'page': page,
+            'filelisting': filelisting,
+            'query': query,
+            'title': _(u'FileBrowser'),
+            'is_popup': "pop" in request.REQUEST,   # ChangeList uses "pop"
+            'settings_var': get_settings_var(directory=self.directory),
+            'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
+            'breadcrumbs_title': "",
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def createdir(self, request):
         "Create Directory"
@@ -376,38 +383,30 @@ class FileBrowserSite(object):
         else:
             form = CreateDirForm(path, filebrowser_site=self)
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/createdir.html', dict(
-            admin_site.each_context(request),
-            **{
-                'form': form,
-                'query': query,
-                'title': _(u'New Folder'),
-                'is_popup': "pop" in request.GET,
-                'settings_var': get_settings_var(directory=self.directory),
-                'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
-                'breadcrumbs_title': _(u'New Folder'),
-                'filebrowser_site': self
-            }
-        ))
+        return render_to_response('filebrowser/createdir.html', {
+            'form': form,
+            'query': query,
+            'title': _(u'New Folder'),
+            'is_popup': "pop" in request.REQUEST,
+            'settings_var': get_settings_var(directory=self.directory),
+            'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
+            'breadcrumbs_title': _(u'New Folder'),
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def upload(self, request):
         "Multipe File Upload."
         query = request.GET
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/upload.html', dict(
-            admin_site.each_context(request),
-            **{
-                'query': query,
-                'title': _(u'Select files to upload'),
-                'is_popup': "pop" in request.GET,
-                'settings_var': get_settings_var(directory=self.directory),
-                'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
-                'breadcrumbs_title': _(u'Upload'),
-                'filebrowser_site': self
-            }
-        ))
+        return render_to_response('filebrowser/upload.html', {
+            'query': query,
+            'title': _(u'Select files to upload'),
+            'is_popup': "pop" in request.REQUEST,
+            'settings_var': get_settings_var(directory=self.directory),
+            'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
+            'breadcrumbs_title': _(u'Upload'),
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def delete_confirm(self, request):
         "Delete existing File/Directory."
@@ -415,7 +414,7 @@ class FileBrowserSite(object):
         path = u'%s' % os.path.join(self.directory, query.get('dir', ''))
         fileobject = FileObject(os.path.join(path, query.get('filename', '')), site=self)
         if fileobject.filetype == "Folder":
-            filelisting = self.filelisting_class(
+            filelisting = FileListing(
                 os.path.join(path, fileobject.filename),
                 sorting_by=query.get('o', 'filename'),
                 sorting_order=query.get('ot', DEFAULT_SORTING_ORDER),
@@ -430,22 +429,18 @@ class FileBrowserSite(object):
             filelisting = None
             additional_files = None
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/delete_confirm.html', dict(
-            admin_site.each_context(request),
-            **{
-                'fileobject': fileobject,
-                'filelisting': filelisting,
-                'additional_files': additional_files,
-                'query': query,
-                'title': _(u'Confirm delete'),
-                'is_popup': "pop" in request.GET,
-                'settings_var': get_settings_var(directory=self.directory),
-                'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
-                'breadcrumbs_title': _(u'Confirm delete'),
-                'filebrowser_site': self
-            }
-        ))
+        return render_to_response('filebrowser/delete_confirm.html', {
+            'fileobject': fileobject,
+            'filelisting': filelisting,
+            'additional_files': additional_files,
+            'query': query,
+            'title': _(u'Confirm delete'),
+            'is_popup': "pop" in request.REQUEST,
+            'settings_var': get_settings_var(directory=self.directory),
+            'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
+            'breadcrumbs_title': _(u'Confirm delete'),
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def delete(self, request):
         "Delete existing File/Directory."
@@ -500,7 +495,7 @@ class FileBrowserSite(object):
                     if isinstance(action_response, HttpResponse):
                         return action_response
                     if "_continue" in request.POST:
-                        redirect_url = reverse("filebrowser:fb_detail", current_app=self.name) + query_helper(query, "filename=" + new_name, "filename")
+                        redirect_url = reverse("filebrowser:fb_detail", current_app=self.name) + query_helper(query, "filename="+new_name, "filename")
                     else:
                         redirect_url = reverse("filebrowser:fb_browse", current_app=self.name) + query_helper(query, "", "filename")
                     return HttpResponseRedirect(redirect_url)
@@ -509,21 +504,17 @@ class FileBrowserSite(object):
         else:
             form = ChangeForm(initial={"name": fileobject.filename}, path=path, fileobject=fileobject, filebrowser_site=self)
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/detail.html', dict(
-            admin_site.each_context(request),
-            **{
-                'form': form,
-                'fileobject': fileobject,
-                'query': query,
-                'title': u'%s' % fileobject.filename,
-                'is_popup': "pop" in request.GET,
-                'settings_var': get_settings_var(directory=self.directory),
-                'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
-                'breadcrumbs_title': u'%s' % fileobject.filename,
-                'filebrowser_site': self
-            }
-        ))
+        return render_to_response('filebrowser/detail.html', {
+            'form': form,
+            'fileobject': fileobject,
+            'query': query,
+            'title': u'%s' % fileobject.filename,
+            'is_popup': "pop" in request.REQUEST,
+            'settings_var': get_settings_var(directory=self.directory),
+            'breadcrumbs': get_breadcrumbs(query, query.get('dir', '')),
+            'breadcrumbs_title': u'%s' % fileobject.filename,
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def version(self, request):
         """
@@ -534,28 +525,19 @@ class FileBrowserSite(object):
         path = u'%s' % os.path.join(self.directory, query.get('dir', ''))
         fileobject = FileObject(os.path.join(path, query.get('filename', '')), site=self)
 
-        request.current_app = self.name
-        return TemplateResponse(request, 'filebrowser/version.html', dict(
-            admin_site.each_context(request),
-            **{
-                'fileobject': fileobject,
-                'query': query,
-                'settings_var': get_settings_var(directory=self.directory),
-                'filebrowser_site': self
-            }
-        ))
+        return render_to_response('filebrowser/version.html', {
+            'fileobject': fileobject,
+            'query': query,
+            'settings_var': get_settings_var(directory=self.directory),
+            'filebrowser_site': self
+        }, context_instance=Context(request, current_app=self.name))
 
     def _upload_file(self, request):
         """
         Upload file to the server.
-
-        If temporary is true, we upload to UPLOAD_TEMPDIR, otherwise
-        we upload to site.directory
         """
         if request.method == "POST":
             folder = request.GET.get('folder', '')
-            temporary = request.GET.get('temporary', '')
-            temp_filename = None
 
             if len(request.FILES) == 0:
                 return HttpResponseBadRequest('Invalid request! No files included.')
@@ -567,11 +549,7 @@ class FileBrowserSite(object):
             fb_uploadurl_re = re.compile(r'^.*(%s)' % reverse("filebrowser:fb_upload", current_app=self.name))
             folder = fb_uploadurl_re.sub('', folder)
 
-            # temporary upload folder should be outside self.directory
-            if folder == UPLOAD_TEMPDIR and temporary == "true":
-                path = folder
-            else:
-                path = os.path.join(self.directory, folder)
+            path = os.path.join(self.directory, folder)
             # we convert the filename before uploading in order
             # to check for existing files/folders
             file_name = convert_filename(filedata.name)
@@ -579,12 +557,6 @@ class FileBrowserSite(object):
             file_path = os.path.join(path, file_name)
             file_already_exists = self.storage.exists(file_path)
 
-            # construct temporary filename by adding the upload folder, because
-            # otherwise we don't have any clue if the file has temporary been
-            # uploaded or not
-            if folder == UPLOAD_TEMPDIR and temporary == "true":
-                temp_filename = os.path.join(folder, file_name)
-
             # Check for name collision with a directory
             if file_already_exists and self.storage.isdir(file_path):
                 ret_json = {'success': False, 'filename': file_name}
@@ -594,30 +566,18 @@ class FileBrowserSite(object):
             uploadedfile = handle_file_upload(path, filedata, site=self)
 
             if file_already_exists and OVERWRITE_EXISTING:
-                old_file = smart_str(file_path)
-                new_file = smart_str(uploadedfile)
+                old_file = smart_text(file_path)
+                new_file = smart_text(uploadedfile)
                 self.storage.move(new_file, old_file, allow_overwrite=True)
-                full_path = FileObject(smart_str(old_file), site=self).path_full
             else:
-                file_name = smart_str(uploadedfile)
+                file_name = smart_text(uploadedfile)
                 filedata.name = os.path.relpath(file_name, path)
-                full_path = FileObject(smart_str(file_name), site=self).path_full
 
-            # set permissions
-            if DEFAULT_PERMISSIONS is not None:
-                os.chmod(full_path, DEFAULT_PERMISSIONS)
-
-            f = FileObject(smart_str(file_name), site=self)
-            signals.filebrowser_post_upload.send(sender=request, path=folder, file=f, site=self)
+            signals.filebrowser_post_upload.send(sender=request, path=folder, file=FileObject(smart_text(file_name), site=self), site=self)
 
             # let Ajax Upload know whether we saved it or not
-            ret_json = {
-                'success': True,
-                'filename': f.filename,
-                'temp_filename': temp_filename,
-                'url': f.url,
-            }
-            return HttpResponse(json.dumps(ret_json), content_type="application/json")
+            ret_json = {'success': True, 'filename': file_name}
+            return HttpResponse(json.dumps(ret_json))
 
 storage = DefaultStorage()
 # Default FileBrowser site
